#
# spec file for package NetworkManager-openconnect
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-openconnect
Version:        1.2.6
Release:        lp153.1.31
Summary:        NetworkManager VPN support for OpenConnect
License:        GPL-2.0-or-later AND LGPL-2.1-only
Group:          Productivity/Networking/System
URL:            http://www.gnome.org/projects/NetworkManager
Source0:        https://download.gnome.org/sources/NetworkManager-openconnect/1.2/%{name}-%{version}.tar.xz

BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gcr-3) >= 3.4
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
BuildRequires:  pkgconfig(libnm) >= 1.1.0
BuildRequires:  pkgconfig(libsecret-unstable)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openconnect) >= 3.02
Requires:       %{name}-frontend
Requires:       NetworkManager >= 1.1.0
Requires:       openconnect
Requires(pre):  pwdutils
Recommends:     %{name}-lang
ExcludeArch:    s390 s390x

%description
NetworkManager-openconnect provides VPN support to NetworkManager for
OpenConnect, an implementation of the Cisco AnyConnect VPN system.

%package gnome
Summary:        NetworkManager VPN support for OpenConnect
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Provides:       %{name}-frontend

%description gnome
NetworkManager-openconnect provides VPN support to NetworkManager for
OpenConnect, an implementation of the Cisco AnyConnect VPN system.

%lang_package

%prep
%autosetup -p1
translation-update-upstream

%build
%configure \
        --disable-static \
        --without-libnm-glib \
        %{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%pre
getent group  nm-openconnect >/dev/null || groupadd -r nm-openconnect
getent passwd nm-openconnect >/dev/null || useradd  -r -g nm-openconnect \
                                                    -d %{_localstatedir}/lib/nm-openconnect \
                                                    -s /sbin/nologin \
                                                    -c "NetworkManager user for OpenConnect" \
                                                    nm-openconnect
exit 0

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%{_libdir}/NetworkManager/libnm-vpn-plugin-openconnect.so
%{_libexecdir}/nm-openconnect-service
%{_libexecdir}/nm-openconnect-service-openconnect-helper
%dir %{_libexecdir}/NetworkManager
%dir %{_libexecdir}/NetworkManager/VPN
%{_libexecdir}/NetworkManager/VPN/nm-openconnect-service.name
%{_sysconfdir}/dbus-1/system.d/nm-openconnect-service.conf

%files gnome
%{_datadir}/appdata/network-manager-openconnect.metainfo.xml
%{_libexecdir}/nm-openconnect-auth-dialog
%{_datadir}/gnome-vpn-properties/
%{_libdir}/NetworkManager/libnm-vpn-plugin-openconnect-editor.so

%files lang -f %{name}.lang

%changelog
* Wed Aug  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.6:
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default. It can be enabled by passing --with-libnm-glib to
    configure script. Nobody should need it by now. Users that
    still use this are encouraged to let us know before the
    libnm-glib support is removed for good.
  + Allow key files for TPM v2.0 to be configured.
  + Add support for PAN GlobalProtect and native Pulse Secure
    protocol.
  + Discourage users from accepting bad server certificates.
  + Add persistent support (beware
    https://bugzilla.gnome.org/794190 though).
- Add pkgconfig(gcr-3) BuildRequires: New dependency.
- Use modern macros.
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Following changes in NetworkManager: pass without-libnm-glib to
  configure, no longer build deprecated libnm-glib support.
- Following the above changes: Drop no longer needed
  pkgconfig(NetworkManager), pkgconfig(libnm-glib),
  pkgconfig(libnm-glib-vpn) and pkgconfig(libnm-util)
  BuildRequires.
- Drop no longer needed export CFLAGS="%%%%{optflags}
  - Wno-deprecated-declarations".
- Drop unnneeded NetworkManager-gnome Requires from gnome
  sub-package, it is not longer of use for us.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Dec  6 2016 dimstar@opensuse.org
- Update to version 1.2.4:
  + Split libnm-vpn-plugin-openconnect.so into a GTK-free core
    plugin usable by nmcli and a UI plugin for nm-applet and GNOME
    components.
  + Support NM_VPN_LOG_LEVEL environment variable to control debug
    logging from NetworkManager.
  + Support Juniper Network Connect / Junos Pulse Secure VPN.
  + Add Yubikey OATH support.
  + Added support for automatic login when all needed data is
    known.
  + Fixed support for IPv6-only VPNs.
  + Updated translations.
* Sat May 14 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Use a proper name for the AppStream metadata.
  + Updated translations.
* Mon May  2 2016 dimstar@opensuse.org
- Update to version 1.2.0:
  + build: don't include the full path to a plugin by default.
  + Updated translations.
* Wed Apr  6 2016 dimstar@opensuse.org
- Update to version 1.1.93 (1.2-rc1):
  + No changes.
- Changes from version 1.1.92:
  + plugin: avoid calling GetAll on service object.
  + Updated translations.
* Tue Mar  1 2016 dimstar@opensuse.org
- Update to version 1.1.91:
  + service: drop off the bus if the peer vanishes or we're
    unneeded.
  + Updated translations.
* Thu Jan 21 2016 dimstar@opensuse.org
- Update to version 1.1.90:
  + Ported to libnm, libnma and GDBus.
  + Support multiple concurrent VPN connections.
  + Updated translations.
- Add pkgconfig(libnm) BuildRequires: new dependency.
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 1.0.8:
  + Updated translations.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 1.0.2:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Replace openconnect-devel BuildRequires with
  pkgconfig(openconnect), matching what configure checks for.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 1.0.0:
  + Dropped support for libopenconnect.so.1.
  + Added support for libopenconnect.so.4.
  + Added support HMAC-based One Time Password (HOTP).
  + Updated translations.
- Drop NetworkManager-openconnect-7.0.patch: fixed upstream.
* Mon Dec  8 2014 dimstar@opensuse.org
- Add NetworkManager-openconnect-7.0.patch: Fix build with
  OpenConnect 7.0. Patch taken from git, commit 58944a3.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.9.10.0:
  + Use libsecret for password storage instead of gnome-keyring.
  + Updated translations.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams switch to
  libsecret.
* Sun Mar 16 2014 zaitor@opensuse.org
- Update to version 0.9.8.6:
  + Add support for OpenConnect 6.0.
  + Allow alpha-numeric software token secrets instead of only
    numeric ones.
  + Add support for TOTP tokens.
  + Hide irrelevant options from the auth dialog.
  + Show correct options when user selects a different auth group.
  + Updated translations.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.9.8.4:
  + Fixed paths in VPN service file.
  + Fixed localization in non-UTF-8 locales.
  + Removed spurious GConf dependency.
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed.
* Thu Jul 11 2013 dimstar@opensuse.org
- Add -Wno-deprecated-declarations to CFLAGS to not fail on
  use of deprecated symbols of GTK+ 3.9.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Automatically start if there's only one host.
  + Updated translations.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 0.9.8.0:
  + Builds against the GNOME 3.8 versions of GLib and Gtk+.
  + Software Tokens are now supported (if libopenconnect has support
    for them).
  + Fixed typos in several messages.
  + nm-openconnect-service now returns translated error messages.
  + Updated translations.
- Drop NetworkManager-openconnect-g_type_init.patch, fixed
  upstream.
* Sat Jan 12 2013 dimstar@opensuse.org
- Add NetworkManager-openconnect-g_type_init.patch: g_type_init()
  is deprecated. Fix build with glib 2.35.x.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 0.9.6.2:
  + Ensure IPv6 UI components appear in the editor.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 0.9.6.0:
  + Do not fail if no IPv6 address is retrieved.
  + Ensure invalid IPv6 address triggers an error.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 0.9.5.95:
  + Better handling of connection cancellation.
  + Add IPv6 support.
  + Allow building with gnutls instead of openssl.
  + Use multiple domains if given.
  + Store passwords in GNOME keyring.
  + Updated translations.
- Add pkgconfig(gnome-keyring-1) BuildRequires: New dependency.
- Drop NetworkManager-openconnect-0.9.4-dropping_privs_check.patch:
  fixed upstream.
* Fri Mar 30 2012 toddrme2178@gmail.com
- Add NetworkManager-openconnect-0.9.4-dropping_privs_check.patch:
  check for success when dropping privileges. This issue was raised
  by the security team in bnc#732915, comments 13-16. Patch taken
  from upstream.
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 0.9.4.0:
  + Build system changes.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.9.3.995:
  + Misc bug fixes.
  + Updated translations.
- Drop upstream merged patches:
  + nm-openconnect-0.9.2.0-g_thread_init.patch
  + nm-openconnect-0.9.2.0-g_thread_new.patch
  + nm-openconnect-0.9.2.0-gmutex.patch
  + nm-openconnect-0.9.2.0-gtk_box_new.patch
  + nm-openconnect-0.9.2.0-gtypes.patch
* Wed Dec 21 2011 vuntz@opensuse.org
- Remove rpmlintrc: the dbus service is now authorized (see
  bnc#732915).
- Remove pkgconfig(gnome-keyring-1) BuildRequires: it's not needed.
- Add explicit pkgconfig(libnm-glib-vpn) BuildRequires.
- Do not  call %%icon_theme_cache_post/%%icon_theme_cache_postun in
  scriptlets for the gnome subpackage: there is no icon shipped in
  the package.
- Various cleanups for inclusion in Factory.
* Mon Nov 28 2011 toddrme2178@gmail.com
- Create the nm-openconnect user, as per discussion in bnc#732915.
- Fix license (at least according to Fedora): one binary is
  LGPL-2.1.
* Tue Nov  8 2011 toddrme2178@gmail.com
- Initial spec file
